SyllaPy
=======

<p>
  <a href="https://badge.fury.io/py/syllapy"><img src="https://badge.fury.io/py/syllapy.svg" alt="PyPI version"></a>
  <a href="https://mholtzscher.visualstudio.com/syllapy/_build"><img src="https://mholtzscher.visualstudio.com/syllapy/_apis/build/status/mholtzscher.syllapy?branchName=master" alt="Azure Pipelines"></a>
  <a href="https://github.com/mholtzscher/syllapy"><img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Black"></a>
  <a href="https://codecov.io/gh/mholtzscher/syllapy">
  <img src="https://codecov.io/gh/mholtzscher/syllapy/branch/master/graph/badge.svg" alt="Codecov"/></a>
</p>

Calculate syllable counts for English words.


Installation
------------

``` {.sourceCode .python}
pip install syllapy
```

Usage
-----

``` {.sourceCode .python}
import syllapy
count = syllapy.count('additional')
```

